Learn R Programming

appler (version 0.2.1)

lookup_apple: Apple Store Lookup

Description

You can create a lookup request to search for content in the stores based on iTunes IDs, UPCs/EANs, and All Music Guide (AMG) IDs. ID-based lookups are faster and contain fewer false-positive results.

Usage

lookup_apple(
  id,
  country = NULL,
  entity = NULL,
  limit = NULL,
  sort = NULL,
  id_type = "id"
)

Value

A data.frame of any results that match the iTunes database.

If there were no successful results then it will return NULL.

Arguments

id

The ID of the iTunes entity

country

The two-letter country code for the store you want to search. For a list of country codes see https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2

entity

Optional The type of results you want returned, relative to the specified media type.

limit

Optional The number of search results you want the iTunes Store to return between 1 and 200. The default is 50.

sort

Optional The order the results are returned, for most recent first select recent.

id_type

The ID type to lookup, options are:

id

The default iTunes ID

amgArtistId

AMG Artist ID

amgAlbumId

AMG Album ID

upc

UPC Album or Video ID

isbn

ISB Book ID

See Also

Examples

Run this code
if (FALSE) { # interactive()
# Search for all Jack Johnson audio and video content
search_apple(term = "Jack Johnson")

# Look up Jack Johnson by iTunes artist ID
lookup_apple(909253)

# Look up Jack Johnson by AMG artist ID
lookup_apple(468749, id_type = "amgArtistId")
}

Run the code above in your browser using DataLab